pub fn parse_initialize_event_rpc(log: &RpcLog) -> Result<PoolCreatedEvent>Expand description
Parses a UniswapV4 Initialize event from an RPC log.
Errors
Returns an error if the log parsing fails or if the event data is invalid.
pub fn parse_initialize_event_rpc(log: &RpcLog) -> Result<PoolCreatedEvent>Parses a UniswapV4 Initialize event from an RPC log.
Returns an error if the log parsing fails or if the event data is invalid.